# heychef

🍳 **Multi-Agent Orchestrator CLI**

This package name is reserved for the Wonged-Kitchen project.

Full release coming soon!

## About

`heychef` is a command-line interface for orchestrating AI agents in a kitchen brigade system.

Commands like:
- `heychef fire` - Start the kitchen
- `heychef status` - Check kitchen status  
- `heychef pickup` - Review completed work

Visit: https://github.com/Dimmoro/Wonged-Kitchen
